.. title:: OTP-CR-117/19

.. raw:: html

    <br><br><br><br><br><br>

.. image:: skullband2.jpg
    :align: center
    :target: admin.html

.. raw:: html

    <br><br><br><br><br><br><br><br><br><br><br>

**GENOCIDE** contains correspondence with the International Criminal Court, asking for arrest of the king of the netherlands, for the genocide he is committing with his new treatement laws. Current status is an outside the jurisdiction judgement of the prosecutor which requires a reconsider to have the king actually arrested, see
:ref:`here <reconsider>`.

.. toctree::
    :hidden:
    :glob:

    *
    